RustlsMtlsExt

Trait RustlsMtlsExt 

pub trait RustlsMtlsExt {
    // Required methods
    fn server_config_mtls_rustls(&self) -> ServerConfig;
    fn server_config_mtls_rustls_with_provider(
        &self,
        provider: Arc<CryptoProvider>,
    ) -> ServerConfig;
    fn client_config_mtls_rustls(&self) -> ClientConfig;
    fn client_config_mtls_rustls_with_provider(
        &self,
        provider: Arc<CryptoProvider>,
    ) -> ClientConfig;
}
Extension trait for mutual TLS configurations.

Required Methods

fn server_config_mtls_rustls(&self) -> ServerConfig

Build a ServerConfig that requires client certificates verified against the chain’s root CA.

fn server_config_mtls_rustls_with_provider( &self, provider: Arc<CryptoProvider>, ) -> ServerConfig

Build a ServerConfig for mTLS with an explicit CryptoProvider.

fn client_config_mtls_rustls(&self) -> ClientConfig

Build a ClientConfig that presents the leaf certificate as a client certificate and trusts the root CA.

fn client_config_mtls_rustls_with_provider( &self, provider: Arc<CryptoProvider>, ) -> ClientConfig

Build a ClientConfig for mTLS with an explicit CryptoProvider.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl RustlsMtlsExt for X509Chain

Available on crate features client-config and server-config and x509 only.

Implementors